==> apache-cxf-3.4.7-src.tar.gz: apache-cxf-3.4.7-src/integration/cdi/src/main/java/org/apache/cxf/cdi/Lifecycle.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.cdi;

import javax.enterprise.context.spi.CreationalContext;
import javax.enterprise.inject.spi.Bean;
import javax.enterprise.inject.spi.BeanManager;

class Lifecycle {
    private final BeanManager beanManager;
    private final Bean<?> bean;
    private Object instance;
    private CreationalContext<?> context;

    Lifecycle(final BeanManager beanManager, final Bean<?> bean) {
        this.beanManager = beanManager;
        this.bean = bean;
    }

    Object create() {
        context = beanManager.createCreationalContext(bean);
        instance = beanManager.getReference(bean, bean.getBeanClass(), context);
        return instance;
    }

    void destroy() {
        if (context != null) {
            context.release();
            instance = null;
            context = null;
        }
    }
}

==> apache-cxf-4.0.7-src.tar.gz: apache-cxf-4.0.7-src/integration/cdi/src/main/java/org/apache/cxf/cdi/Lifecycle.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.cdi;

import jakarta.enterprise.context.spi.CreationalContext;
import jakarta.enterprise.inject.spi.Bean;
import jakarta.enterprise.inject.spi.BeanManager;

class Lifecycle {
    private final BeanManager beanManager;
    private final Bean<?> bean;
    private Object instance;
    private CreationalContext<?> context;

    Lifecycle(final BeanManager beanManager, final Bean<?> bean) {
        this.beanManager = beanManager;
        this.bean = bean;
    }

    Object create() {
        context = beanManager.createCreationalContext(bean);
        instance = beanManager.getReference(bean, bean.getBeanClass(), context);
        return instance;
    }

    void destroy() {
        if (context != null) {
            context.release();
            instance = null;
            context = null;
        }
    }
}
